@@ -40,18 +40,19 @@
 #include "gdm-signal-handler.h"
 #include "gdm-log.h"
 
-#include "gsm-gconf.h"
 #include "gsm-util.h"
 #include "gsm-manager.h"
 #include "gsm-session-fill.h"
 #include "gsm-store.h"
 #include "gsm-xsmp-server.h"
+#include "gsm-fail-whale-dialog.h"
 
 #define GSM_DBUS_NAME "org.gnome.SessionManager"
 
 static gboolean failsafe = FALSE;
 static gboolean show_version = FALSE;
 static gboolean debug = FALSE;
+static gboolean please_fail = FALSE;
 
 static void
 on_bus_name_lost (DBusGProxy *bus_proxy,
@@ -278,6 +279,7 @@ main (int argc, char **argv)
                 { "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debugging code"), NULL },
                 { "failsafe", 'f', 0, G_OPTION_ARG_NONE, &failsafe, N_("Do not load user-specified applications"), NULL },
                 { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Version of this application"), NULL },
+                { "whale", 0, 0, G_OPTION_ARG_NONE, &please_fail, N_("Show the fail whale dialog for testing"), NULL },
                 { NULL, 0, 0, 0, NULL, NULL, NULL }
         };
 
@@ -310,6 +312,12 @@ main (int argc, char **argv)
                 exit (1);
         }
 
+        if (please_fail) {
+                gsm_fail_whale_dialog_we_failed (TRUE, TRUE, TRUE);
+                gtk_main ();
+                exit (1);
+        }
+
         gdm_log_init ();
         gdm_log_set_debug (debug);
 
@@ -327,16 +335,8 @@ main (int argc, char **argv)
 
         client_store = gsm_store_new ();
 
-
-        /* Start up gconfd if not already running. */
-        gsm_gconf_init ();
-
         xsmp_server = gsm_xsmp_server_new (client_store);
 
-        /* Now make sure they succeeded. (They'll call
-         * gsm_util_init_error() if they failed.)
-         */
-        gsm_gconf_check ();
         acquire_name ();
 
         manager = gsm_manager_new (client_store, failsafe);
@@ -377,8 +377,6 @@ main (int argc, char **argv)
                 g_object_unref (client_store);
         }
 
-        gsm_gconf_shutdown ();
-
         gdm_log_shutdown ();
 
         return 0;
